package Mail::Chimp;
use Mouse;

our $VERSION     = '0.11';

=head1 NAME

Mail::Chimp - Perl wrapper around the Mailchimp v1.1 API

=head1 DESCRIPTION

You should look at Mail::Chimp::API instead.

=head1 DEPENDENCIES

 Mouse
 XMLRPC::Lite

=head1 SEE ALSO

 XMLRPC::Lite
 <http://api.mailchimp.com/1.1/>

=head1 COPYRIGHT

Copyright (C) 2009 Dave Pirotte.  All rights reserved.

This library is free software; you can redistribute it and/or modify it under the same terms as Perl itself.

=head1 AUTHOR

Dave Pirotte (dpirotte@gmail.com)

=cut

1;
